import streamlit.components.v1 as components

def markmap(data, height=600):
    data = str(data)
    markdown_style = '''
            <style>
                svg {{
                    width: 100%;
                    height: {}px;
                }}
            </style>'''.format(height)
    markdown_html = f'''
        {markdown_style}
        <script src="https://cdn.jsdelivr.net/npm/markmap-autoloader"></script>
            
        <div class='markmap'>{data}</div>
    '''

    markmap_component = components.html(markdown_html, height=height)
    return markmap_component



import setuptools

setuptools.setup(
    name="streamlit-markmap",
    version="1.0.1",
    author="echoopen",
    author_email="632019805@qq.com",
    description="markmap",
    long_description="",
    long_description_content_type="text/plain",
    url="",
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[],
    python_requires=">=3.6",
    install_requires=[
        "streamlit >= 0.63",
    ],
)
